##  Antipatterns
This section addresses common pitfalls and antipatterns involving counterproductive ways of modeling applications in SAP LeanIX.
  * Application vs. IT component: A common pitfall is confusing applications with IT components.
    * Classical business applications, like ERP systems, are clearly applications. In contrast, operating systems, databases, and virtual machines are IT components.
    * Consider the software architecture to distinguish between the two: applications typically include data, logic, and presentation layers, while IT components do not. If an entity lacks a data or business logic layer, it is likely an IT component.
    * If the entity provides data and business logic to other applications and possibly business users, it is best modeled as an application. For example, if a spreadsheet serves a specific business task, such as a quoting tool or usage analytics, the spreadsheet itself is considered an application, while the spreadsheet software, like Excel, is an IT component of the subtype software.
    * System software, technology services, or hardware (e.g., operating systems, databases, runtime environments, laptops, desktop computers, and other devices) are IT components.
  * Versioning: In most cases, versioning for applications doesn’t add significant value and should only be used if it’s relevant to your use case.
  * Directly linking applications to providers: Linking applications directly to providers through custom relations in the meta model might initially seem like a time-saving measure. However, this approach can severely restrict reporting capabilities in the long term, including cost reporting and obsolescence risk management.
  * Microservice Modeling: SAP LeanIX is not suited to modeling a live microservices landscape. Tracking every microservice, software library, and technical detail manually all of the time can become difficult and can clutter your EA landscape. If you model microservices, automate the process and focus your effort on generating relevant insights for your business. For guidelines on modeling microservices, see [Modeling Microservices](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for microservices. Learn best practices for tracking their provisioning and dependencies effectively and avoid common antipatterns.").
